/******************************************************************************

Copyright (c) 2020 The Linux Foundation. All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:
        * Redistributions of source code must retain the above copyright
          notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above
          copyright notice, this list of conditions and the following
          disclaimer in the documentation and/or other materials provided
          with the distribution.
        * Neither the name of The Linux Foundation nor the names of its
          contributors may be used to endorse or promote products derived
          from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT
ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

******************************************************************************/
#ifndef _MMDATA_QRTR_H_
#define _MMDATA_QRTR_H_

#include "libqrtr.h"
#include "mmdata_main.h"
#include "mmdata_rmnet.h"


/*===========================================================================
                     GLOBAL DEFINITIONS AND DECLARATIONS
===========================================================================*/

#define QRTR_HEADER_SIZE                (7)
#define MSG_NUM_CHARS_PER_BYTE          (3)
#define MSG_NUM_BYTES_PER_LINE          (16)

#define QRTR_CLIENT_PORT    (0)
#define QRTR_SOCK_INVALID   (0)

#define MMDATA_QRTR_TIMEOUT       (30000)

#define GET_HEX_CHAR(x)  \
       (((x) > 0x0F) ? '*' : hex_digit_to_char_tbl[(x)])

static const char hex_digit_to_char_tbl[] =
  { '0', '1', '2', '3', '4', '5', '6', '7',  '8', '9', 'A', 'B', 'C', 'D', 'E', 'F' };

static inline uint32_t le32_to_cpu(__le32 x) { return le32toh(x); }

typedef struct {
  int       lookup_sock;
  int       data_sock;
  uint32_t  service;
  uint32_t  version;
  uint32_t  instance;
  uint32_t  node;
  uint32_t  port;
}qrtr_client_info;

void print_qrtr_msg
(
  const unsigned char  *msg,
  int                  msg_len
);

int qrtr_client_init
(
  qrtr_client_info  *client_info,
  int             timeout
);

int
qrtr_client_release
(
  qrtr_client_info  *client_info
);

#endif
